# Generated by roxygen2: do not edit by hand

S3method(st_as_sfc,TWKB)
S3method(st_force_polygon_cw,sf)
S3method(st_force_polygon_cw,sfc)
S3method(st_force_polygon_cw,sfg)
S3method(st_is_polygon_cw,sf)
S3method(st_is_polygon_cw,sfc)
S3method(st_is_polygon_cw,sfg)
S3method(st_linesubstring,sf)
S3method(st_linesubstring,sfc)
S3method(st_linesubstring,sfg)
S3method(st_minimum_bounding_circle,sf)
S3method(st_minimum_bounding_circle,sfc)
S3method(st_minimum_bounding_circle,sfg)
S3method(st_minimum_bounding_radius,sf)
S3method(st_minimum_bounding_radius,sfc)
S3method(st_minimum_bounding_radius,sfg)
S3method(st_snap_to_grid,sf)
S3method(st_snap_to_grid,sfc)
S3method(st_snap_to_grid,sfg)
S3method(st_split,sf)
S3method(st_split,sfc)
S3method(st_split,sfg)
S3method(st_subdivide,sf)
S3method(st_subdivide,sfc)
S3method(st_subdivide,sfg)
S3method(st_transform_proj,sf)
S3method(st_transform_proj,sfc)
S3method(st_transform_proj,sfg)
S3method(st_wrap_x,sf)
S3method(st_wrap_x,sfc)
S3method(st_wrap_x,sfg)
export(lwgeom_extSoftVersion)
export(lwgeom_make_valid)
export(st_asewkt)
export(st_astext)
export(st_endpoint)
export(st_force_polygon_cw)
export(st_geod_area)
export(st_geod_azimuth)
export(st_geod_covered_by)
export(st_geod_covers)
export(st_geod_distance)
export(st_geod_length)
export(st_geod_segmentize)
export(st_geohash)
export(st_geom_from_geohash)
export(st_is_polygon_cw)
export(st_linesubstring)
export(st_minimum_bounding_circle)
export(st_minimum_bounding_radius)
export(st_perimeter)
export(st_perimeter_2d)
export(st_perimeter_lwgeom)
export(st_snap_to_grid)
export(st_split)
export(st_startpoint)
export(st_subdivide)
export(st_transform_proj)
export(st_wrap_x)
import(sf)
importFrom(Rcpp,evalCpp)
importFrom(units,as_units)
importFrom(units,set_units)
importFrom(utils,tail)
useDynLib(lwgeom)
