liblwgeom code obtained from from https://github.com/postgis/postgis
git commit d9a98c5be3c8644699220729f11ed48488548bad
configured with:
./configure --without-pgconfig --without-sfcgal --without-libiconv-prefix --without-libintl-prefix --without-json --without-protobuf --without-topology --without-raster  

removed: *_sfcgal.[ch]

all diffs, registered with "diff -c | grep -v 'Only in'", are found in file DIFFS

In addition: postgis_version.h, outcomment line 139 which defines
POSTGIS_GEOS_VERSION; ./configure now does this on the command line.

in addition: "%.*g" -> "%*g" in lwgeom_wkt.c
