% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/perimeter.R
\name{perimeter}
\alias{perimeter}
\alias{st_perimeter_lwgeom}
\alias{st_perimeter_2d}
\title{Compute perimeter from polygons or other geometries}
\usage{
st_perimeter_lwgeom(x)

st_perimeter_2d(x)
}
\arguments{
\item{x}{object of class \code{sf}, \code{sfc} or \code{sfg}}
}
\value{
numerical vector with perimeter for each feature (geometry), with unit of measure when possible
}
\description{
Compute perimeter from polygons or other geometries
}
